
.. _`MOF compiler`:

MOF compiler
============

.. automodule:: pywbem._mof_compiler

.. _`MOFCompiler Class`:

MOFCompiler Class
-----------------

.. autoclass:: pywbem.MOFCompiler
    :members:
    :special-members:
    :exclude-members: __init__,__weakref__
    :autosummary:
    :autosummary-inherited-members:


.. _`Repository connections`:

Repository connections
----------------------

.. autoclass:: pywbem.BaseRepositoryConnection
    :members:
    :special-members:
    :exclude-members: __init__,__weakref__
    :autosummary:
    :autosummary-inherited-members:

.. autoclass:: pywbem.MOFWBEMConnection
    :members:
    :special-members:
    :exclude-members: __init__,__weakref__
    :autosummary:
    :autosummary-inherited-members:


.. _`MOF compiler exceptions`:

Exceptions
----------

The MOF compiler API raises exceptions that are derived from the common base
class :exc:`~pywbem.MOFCompileError`.

.. autoclass:: pywbem.MOFCompileError
    :members:
    :special-members:
    :exclude-members: __init__,__weakref__
    :autosummary:
    :autosummary-inherited-members:

.. autoclass:: pywbem.MOFParseError
    :members:
    :special-members:
    :exclude-members: __init__,__weakref__
    :autosummary:
    :autosummary-inherited-members:

.. autoclass:: pywbem.MOFDependencyError
    :members:
    :special-members:
    :exclude-members: __init__,__weakref__
    :autosummary:
    :autosummary-inherited-members:

.. autoclass:: pywbem.MOFRepositoryError
    :members:
    :special-members:
    :exclude-members: __init__,__weakref__
    :autosummary:
    :autosummary-inherited-members:
